@@ -52,12 +52,12 @@ class SruRequest:
         return self.query == other.query and self.base_url == other.base_url
 
     def __repr__(self) -> str:
-        if self.is_iz_request is False:
-            return (f"{self.__class__.__name__}('{self.query}', limit={self.limit}, "
-                    f"base_url='{self.base_url}')")
-        else:
+        if self.is_iz_request is True:
             return (f"{self.__class__.__name__}('{self.query}', limit={self.limit}, "
                     f"base_url='{self.base_url}', iz_request=True)")
+        else:
+            return (f"{self.__class__.__name__}('{self.query}', limit={self.limit}, "
+                    f"base_url='{self.base_url}')")
 
     def _get_query_path(self) -> str:
         return f'{self.base_url}__{self.query}__{self.limit}'
@@ -147,11 +147,11 @@ class SruRequest:
             if rec_number > self.limit:
                 logging.warning(f'{repr(self)}: number of available results exceed the limit provided')
                 self.are_more_results_available = True
-            if self.is_iz_request is False:
-                new_records = [SruRecord(xml=record, base_url=self.base_url) for record
+            if self.is_iz_request is True:
+                new_records = [IzSruRecord(xml=record, base_url=self.base_url) for record
                                in xml.findall('.//m:record', namespaces=SruClient.nsmap)]
             else:
-                new_records = [IzSruRecord(xml=record, base_url=self.base_url) for record
+                new_records = [SruRecord(xml=record, base_url=self.base_url) for record
                                in xml.findall('.//m:record', namespaces=SruClient.nsmap)]
 
             if len(new_records) == 0:
@@ -329,6 +329,49 @@ class SruRecord:
             logging.critical('Base url for SRU server not defined')
             exit()
 
+    def _fetch_parents_by_std_number(self, xml_field: etree.Element) -> List['SruRecord']:
+        """Fetch parents records by standard number"""
+        # In subfield "x" are ISSN and ISBN
+        for subfield_code in ['x', 'z']:
+            subfield = xml_field.find(f'./m:subfield[@code="{subfield_code}"]', namespaces=SruClient.nsmap)
+            if subfield is not None:
+                break
+
+        if subfield is None:
+            return []
+
+        std_num = subfield.text
+
+        # For the search, hyphen should be removed
+        std_num_cleaned = std_num.replace('-', '')
+
+        # For the search, hyphen should be removed
+        if len(std_num_cleaned) == 8:
+            # Number is probably an ISSN
+            query = f'alma.issn={std_num_cleaned}'
+        elif len(std_num_cleaned) in [10, 13]:
+            # Number is probably an ISBN
+            query = f'alma.isbn={std_num_cleaned}'
+        else:
+            # Type of number unknown
+            query = f'alma.standard_number={std_num_cleaned}'
+
+        req = self.sru_client.fetch_records(query, limit=500)
+        if req.error is True:
+            return []
+
+        if req.are_more_results_available is True:
+            self.warning = True
+            self.warning_messages.append(f'{repr(req)}: not all available parent records examined')
+
+        temp_records = [record for record in req.records
+                        if record.error is False
+                        and record.mms_id != self.mms_id
+                        and std_num in record.get_standard_numbers()
+                        and len([other_sys_id for other_sys_id in record.get_035_fields()
+                                 if other_sys_id.startswith('(CKB)')]) == 0]
+        return temp_records
+
     @check_error
     def get_mms_id(self) -> Optional[str]:
         """get_mms_id(self) -> Optional[str]
@@ -606,10 +649,12 @@ class SruRecord:
                         code = field.attrib['code']
                         tag = field.getparent().attrib['tag']
                         if tag in ['020', '022']:
-                            self.warning = True
-                            self.warning_messages.append(f'More than one record with same {tag}, {self.mms_id} '
-                                                         f'and {record.mms_id} are probably duplicated records')
-                        else:
+                            temp_records_duplicates.add(record)
+                            if code == 'a':
+                                self.warning = True
+                                self.warning_messages.append(f'More than one record with same {tag}, {self.mms_id} '
+                                                             f'and {record.mms_id} are probably duplicated records')
+                        elif tag not in ['020', '022']:
                             fields_related_records.append({'child_MMS_ID': record.mms_id,
                                                            'field': f'{tag}${code}',
                                                            'content': field.text})
@@ -669,7 +714,18 @@ class SruRecord:
                     std_num = subfield.text
 
                     # For the search, hyphen should be removed
-                    query = f'alma.standard_number={std_num.replace("-", "")}'
+                    std_num_cleaned = std_num.replace('-', '')
+
+                    # For the search, hyphen should be removed
+                    if len(std_num_cleaned) == 8:
+                        # Number is probably an ISSN
+                        query = f'alma.issn={std_num_cleaned}'
+                    elif len(std_num_cleaned) in [10, 13]:
+                        # Number is probably an ISBN
+                        query = f'alma.isbn={std_num_cleaned}'
+                    else:
+                        # Type of number unknown
+                        query = f'alma.standard_number={std_num_cleaned}'
 
                     req = self.sru_client.fetch_records(query, limit=500)
                     if req.error is True:
@@ -753,10 +809,19 @@ class SruRecord:
                                     namespaces=SruClient.nsmap)
 
         # $$a contains the IZ, $$6 contains the iz MMS ID, $$9 contains the format ("P", "E" or "D")
-        inventory_info = [{'IZ': f.find('./m:subfield[@code="a"]', namespaces=SruClient.nsmap).text,
-                           'MMS ID': f.find('./m:subfield[@code="6"]', namespaces=SruClient.nsmap).text,
-                           'format': f.find('./m:subfield[@code="9"]', namespaces=SruClient.nsmap).text}
-                          for f in fields852]
+        inventory_info = []
+        for f in fields852:
+
+            # Need to check if the subfields exist, otherwise the script will crash
+            # 852 field are not only result of holdings
+            f_iz = f.find('./m:subfield[@code="a"]', namespaces=SruClient.nsmap)
+            f_mms_id = f.find('./m:subfield[@code="6"]', namespaces=SruClient.nsmap)
+            f_format = f.find('./m:subfield[@code="9"]', namespaces=SruClient.nsmap)
+
+            if f_iz is not None and f_mms_id is not None and f_format is not None:
+                inventory_info.append({'IZ': f_iz.text,
+                                       'MMS ID': f_mms_id.text,
+                                       'format': f_format.text})
         logging.info(f'{repr(self)}: {len(inventory_info)} records in IZ found')
         return inventory_info
 
@@ -961,6 +1026,7 @@ class SruRecord:
 
         with open(f'./records/rec_{self.mms_id}.xml', 'w') as f:
             f.write(str(self))
+
     def get_iz_record(self, server_url: str) -> Optional['IzSruRecord']:
         """get_iz_record(self, server_url: str) -> Optional['IzSruRecord']
         Return :class:`almasru.client.IzSruRecord` from provided server url
@@ -982,8 +1048,6 @@ class SruRecord:
         return None
 
 
-
-
 class IzSruRecord(SruRecord):
     """Class representing a single XML IZ record from SRU
 
@@ -1056,12 +1120,19 @@ class IzSruRecord(SruRecord):
         for field_ava in fields_ava:
             f = {}
             for field in fields:
-                subfield =field_ava.find(f'./m:subfield[@code="{fields[field]}"]', namespaces=SruClient.nsmap)
+                subfield = field_ava.find(f'./m:subfield[@code="{fields[field]}"]', namespaces=SruClient.nsmap)
                 if subfield is not None:
                     f[field] = subfield.text
             inventory_info.append(f)
 
-        logging.info(f'{repr(self)}: {len(inventory_info)} holdings in IZ found')
+        if len(inventory_info) == 0 and self.nz_sru_client is not None:
+            nz_bib = SruRecord(self.get_nz_mms_id(), base_url=self.nz_sru_client.base_url)
+            _ = nz_bib.data
+            if nz_bib.error is False:
+                inventory_info = [{'iz': inventory['IZ']} for inventory in nz_bib.get_inventory_info()
+                                  if inventory['MMS ID'] == self.mms_id]
+
+        logging.info(f'{repr(self)}: inventory in IZ found ({len(inventory_info)})')
         return inventory_info
 
     @check_error
@@ -1171,7 +1242,18 @@ class IzSruRecord(SruRecord):
                     std_num = subfield.text
 
                     # For the search, hyphen should be removed
-                    query = f'alma.standard_number={std_num.replace("-", "")}'
+                    std_num_cleaned = std_num.replace('-', '')
+
+                    # For the search, hyphen should be removed
+                    if len(std_num_cleaned) == 8:
+                        # Number is probably an ISSN
+                        query = f'alma.issn={std_num_cleaned}'
+                    elif len(std_num_cleaned) in [10, 13]:
+                        # Number is probably an ISBN
+                        query = f'alma.isbn={std_num_cleaned}'
+                    else:
+                        # Type of number unknown
+                        query = f'alma.standard_number={std_num_cleaned}'
 
                     req = self.sru_client.fetch_records(query, limit=500)
                     if req.error is True:
@@ -1223,17 +1305,18 @@ class IzSruRecord(SruRecord):
                                              if other_sys_id.startswith('(CKB)')]) == 0
                                     ]
 
+                    # If no record found in the IZ, try in the NZ when mms_id is provided
                     if re.match(r'^99\d{5,}$', sys_num) and self.nz_sru_client is not None:
                         req_nz = self.nz_sru_client.fetch_records(query, limit=500)
                         if req_nz.error is True:
                             continue
 
                         temp_records += [record for record in req_nz.records
-                                        if record.error is False
-                                        and record.mms_id != self.mms_id
-                                        and (record.mms_id == sys_num
-                                             or sys_num in record.get_035_fields())
-                                        and len([other_sys_id for other_sys_id in record.get_035_fields()
+                                         if record.error is False
+                                         and record.mms_id != self.mms_id
+                                         and (record.mms_id == sys_num
+                                              or sys_num in record.get_035_fields())
+                                         and len([other_sys_id for other_sys_id in record.get_035_fields()
                                                  if other_sys_id.startswith('(CKB)')]) == 0]
 
                     records.update(temp_records)
